from setuptools import setup, find_packages

setup(
    name='EasyPage',
    version='0.0.0',
    author='leviathangk',
    author_email='1015295213@qq.com',
    description='基于 CDP 协议，简洁快速的浏览器控制 API',
    packages=find_packages(),
    install_requires=[
    ],
)
